package core.notevault.ui.home;

import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.provider.OpenableColumns;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import com.google.android.material.floatingactionbutton.FloatingActionButton;
import core.notevault.R;
import core.notevault.data.MusicDatabase;
import core.notevault.data.MusicNote;
import core.notevault.data.MusicNoteDAO;
import core.notevault.databinding.FragmentHomeBinding;
import core.notevault.ui.metadatadialog.MetaDataDialog;

import java.util.ArrayList;
import java.util.List;

public class HomeFragment extends Fragment {

    private NoteSongAdapter noteSongAdapter;

    private static final int PICK_FILE_REQUEST_CODE = 1;
    private FragmentHomeBinding binding;
    private HomeViewModel homeViewModel;

    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
         homeViewModel =
                new ViewModelProvider(this).get(HomeViewModel.class);

        binding = FragmentHomeBinding.inflate(inflater, container, false);
        View root = binding.getRoot();

        FloatingActionButton importBtn = root.findViewById(R.id.importMusicNotesBtn);
        importBtn.setOnClickListener(v -> openFileChooser());

        RecyclerView recyclerView = root.findViewById(R.id.note_recycler_view);
        noteSongAdapter = new NoteSongAdapter();
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));

        new LoadSongTitlesTask().execute();

        return root;
    }

    private class LoadSongTitlesTask extends AsyncTask<Void, Void, List<MusicNote>> {

        @Override
        protected List<MusicNote> doInBackground(Void... voids) {
            MusicDatabase db = MusicDatabase.getDatabase(getContext());
            MusicNoteDAO musicNoteDAO = db.musicNoteDao();
            return  musicNoteDAO.getAllNotes();
        }

        @Override
        protected void onPostExecute(List<MusicNote> songTitles) {
            noteSongAdapter.updateSongTitles(songTitles); // Aktualisiere den Adapter mit den Titeln
        }
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == PICK_FILE_REQUEST_CODE && resultCode == getActivity().RESULT_OK && data != null) {
            Uri uri = data.getData();
            if (uri != null) {
                handleFile(uri);
            }
        }
    }

    private void handleFile(Uri uri) {
        // Hier kannst du die Logik zum Speichern oder Anzeigen der Datei implementieren
        MetaDataDialog metaDataDialog = new MetaDataDialog();
        metaDataDialog.setFileUri(uri);
        metaDataDialog.show(getParentFragmentManager(), MetaDataDialog.TAG);

        homeViewModel.addNote(uri); // Speichere die URI im ViewModel
        Toast.makeText(getActivity(), "Datei ausgewählt: " + uri.getPath(), Toast.LENGTH_SHORT).show();
    }

    private void openFileChooser() {
        Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
        intent.setType("*/*"); // Alle Dateitypen

        String[] mimeTypes = {"application/pdf", "image/png", "image/jpeg"};
        intent.putExtra(Intent.EXTRA_MIME_TYPES, mimeTypes);

        intent.addCategory(Intent.CATEGORY_OPENABLE);
        startActivityForResult(intent, PICK_FILE_REQUEST_CODE);
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }


}