package core.notevault.ui.home;

import android.content.Intent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;
import core.notevault.R;
import core.notevault.data.MusicNote;

import java.util.ArrayList;
import java.util.List;

public class NoteSongAdapter extends RecyclerView.Adapter<NoteSongAdapter.NoteViewHolder> {

    private List<MusicNote> noteTitles;

    public NoteSongAdapter(List<MusicNote> noteTitles) {
        this.noteTitles = noteTitles;
    }

    public NoteSongAdapter() {
        this.noteTitles = new ArrayList<>();
    }

    @NonNull
    @Override
    public NoteViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.item_song, parent, false);
        return new NoteViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull NoteViewHolder holder, int position) {
        holder.titleTextView.setText(noteTitles.get(position).getTitle());
    }

    @Override
    public int getItemCount() {
        return noteTitles.size();
    }

    public void updateSongTitles(List<MusicNote> songTitles) {
        this.noteTitles.clear();
        this.noteTitles.addAll(songTitles);
        notifyDataSetChanged();
    }

    public class NoteViewHolder extends RecyclerView.ViewHolder {
        TextView titleTextView;

        public NoteViewHolder(View itemView) {
            super(itemView);
            titleTextView = itemView.findViewById(R.id.note_title);

            titleTextView.setOnClickListener(v -> {
                int position = getAdapterPosition();
                if(position != RecyclerView.NO_POSITION) {
                    MusicNote song = noteTitles.get(position);

                    Intent intent = new Intent(itemView.getContext(), FullScreenImageActivity.class);
                    intent.putExtra("imageUri", song.getFilePath());
                    itemView.getContext().startActivity(intent);
                }
            });
        }
    }
}
