package core.notevault.ui.metadatadialog;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.OpenableColumns;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.DialogFragment;
import core.notevault.R;

public class MetaDataDialog extends DialogFragment {
    private Uri fileUri;

    public interface OnMetadataListener {
        void onMetadataEntered(String title, String composer, int year, String genre);
    }

    private OnMetadataListener listener;

    @NonNull
    @Override
    public Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        LayoutInflater inflater = requireActivity().getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.fragment_metadata_dialog, null); // Ersetze 'your_dialog_layout' durch deinen Dateinamen

        EditText title_input = dialogView.findViewById(R.id.title_input);
        title_input.setText(this.extraxtTitleFromFilePath());
        EditText composer_input = dialogView.findViewById(R.id.composer_input);
        EditText year_input = dialogView.findViewById(R.id.year_input);
        EditText genre_input = dialogView.findViewById(R.id.genre_input);

        return new AlertDialog.Builder(requireContext())
                .setView(dialogView)
                .setPositiveButton("Speichern", (dialog, which) -> {
                    String title = title_input.getText().toString();
                    String composer = composer_input.getText().toString();

                    String year_string = year_input.getText().toString();
                    int year = 0;
                    if(!year_string.isEmpty()) {
                        year = Integer.parseInt(year_input.getText().toString());
                    }

                    String genre = genre_input.getText().toString();

                    listener.onMetadataEntered(title, composer, year, genre);
                } )
                .setNegativeButton("Abbrechen", (dialog, which) -> {} )
                .create();
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        if (context instanceof OnMetadataListener) {
            listener = (OnMetadataListener) context;
        } else {
            throw new RuntimeException(context.toString()
                    + " must implement OnMetadataListener");
        }
    }

    public Uri getFileUri() {
        return fileUri;
    }

    public void setFileUri(Uri fileUri) {
        this.fileUri = fileUri;
    }

    private String extraxtTitleFromFilePath() {
        String fileName = "";

        // Überprüfen, ob die Uri ein Content-Uri ist
        if (this.fileUri.getScheme().equals("content")) {
            // ContentResolver verwenden, um die Datei zu finden
            Cursor cursor = requireContext().getContentResolver().query(this.fileUri, null, null, null, null);
            if (cursor != null) {
                int nameIndex = cursor.getColumnIndex(OpenableColumns.DISPLAY_NAME);
                if (cursor.moveToFirst()) {
                    // Den Dateinamen aus dem Cursor abfragen
                    fileName = cursor.getString(nameIndex);
                }
                cursor.close();
            }
        } else if (this.fileUri.getScheme().equals("file")) {
            // Bei einer Datei-Uri einfach den letzten Pfadsegment verwenden
            fileName = this.fileUri.getLastPathSegment();
        }

        if(fileName.contains(".")) {
            fileName = fileName.substring(0, fileName.lastIndexOf("."));
            fileName = fileName.replace("_", " ");
            fileName = fileName.replace("-", "");
        }

        return fileName;
    }

    public static String TAG = "MetaDataDialog";
}
